@@ -25,11 +25,11 @@ extern "C" {
 /*
 INTERNAL SYMBOLS
 */
-#define  xts_IndexSymbol                install("index")
-#define  xts_ClassSymbol                install(".CLASS")
-#define  xts_IndexFormatSymbol          install(".indexFORMAT")
-#define  xts_IndexClassSymbol           install(".indexCLASS")
-#define  xts_IndexTZSymbol              install(".indexTZ")
+extern SEXP xts_IndexSymbol;
+extern SEXP xts_ClassSymbol;
+extern SEXP xts_IndexTformatSymbol;
+extern SEXP xts_IndexTclassSymbol;
+extern SEXP xts_IndexTzoneSymbol;
 
 /*
 DATA TOOLS
@@ -41,28 +41,26 @@ DATA TOOLS
 #define  GET_xtsIndex(x)                getAttrib(x, xts_IndexSymbol)
 #define  SET_xtsIndex(x,value)          setAttrib(x, xts_IndexSymbol, value)
 
-// attr(x, '.indexCLASS') or indexClass(x)
-#define  GET_xtsIndexClass(x)           getAttrib(x, xts_IndexClassSymbol)
-#define  SET_xtsIndexClass(x,value)     setAttrib(x, xts_IndexvalueSymbol, value)
-
 // attr(x, '.indexFORMAT') or indexFormat(x)
 #define  GET_xtsIndexFormat(x)          getAttrib(x, xts_IndexFormatSymbol)
 #define  SET_xtsIndexFormat(x,value)    setAttrib(x, xts_IndexFormatSymbol, value)
 
-// attr(x, '.indexTZ') or indexTZ(x)
-#define  GET_xtsIndexTZ(x)              getAttrib(x, xts_IndexTZSymbol)
-#define  SET_xtsIndexTZ(x,value)        setAttrib(x, xts_IndexTZSymbol, value)
-
 // attr(x, '.CLASS') or CLASS(x)
 #define  GET_xtsCLASS(x)                getAttrib(x, xts_ClassSymbol)
 #define  SET_xtsCLASS(x,value)          setAttrib(x, xts_ClassSymbol, value)
 
+/*
+IMPORTS FROM zoo
+*/
+extern SEXP(*zoo_lag)(SEXP,SEXP,SEXP);
+extern SEXP(*zoo_coredata)(SEXP,SEXP);
+
 /*
 FUNCTIONS
 */
 SEXP do_xtsAttributes(SEXP x);              // xtsAttributes i.e. user-added attributes
 SEXP do_xtsCoreAttributes(SEXP x);          /* xtsCoreAttributes xts-specific attributes
-                                               CLASS, .indexFORMAT, .indexCLASS & class */
+                                               CLASS, .indexFORMAT, tclass, & class */
 SEXP coredata(SEXP x, SEXP copyAttr);
 SEXP coredata_xts(SEXP x);
 SEXP add_class(SEXP x, SEXP klass);
@@ -73,19 +71,25 @@ SEXP do_rbind_xts(SEXP x, SEXP y, SEXP dup);
 SEXP rbindXts(SEXP args);
 SEXP do_subset_xts(SEXP x, SEXP sr, SEXP sc, SEXP drop);
 SEXP number_of_cols(SEXP args);
-SEXP col_names(SEXP args);
 SEXP naCheck(SEXP x, SEXP check);
 
 SEXP make_index_unique(SEXP x, SEXP eps);
 SEXP make_unique(SEXP X, SEXP eps);
-SEXP endpoints(SEXP x, SEXP on, SEXP addlast);
+SEXP endpoints(SEXP _x, SEXP _on, SEXP _k, SEXP _addlast);
 SEXP do_merge_xts(SEXP x, SEXP y, SEXP all, SEXP fill, SEXP retclass, SEXP colnames, 
-                  SEXP suffixes, SEXP retside, SEXP env, int coerce);
+                  SEXP suffixes, SEXP retside, SEXP check_names, SEXP env, int coerce);
 SEXP na_omit_xts(SEXP x);
-SEXP na_locf(SEXP x, SEXP fromlast, SEXP maxgap);
+SEXP na_locf(SEXP x, SEXP fromlast, SEXP maxgap, SEXP limit);
 
 SEXP tryXts(SEXP x);
 
+SEXP xts_period_min(SEXP data, SEXP index);
+SEXP xts_period_max(SEXP data, SEXP index);
+SEXP xts_period_sum(SEXP data, SEXP index);
+SEXP xts_period_prod(SEXP data, SEXP index);
+
+SEXP xts_set_dimnames(SEXP x, SEXP value);
+
 
 void copyAttributes(SEXP x, SEXP y);    // internal only
 void copy_xtsAttributes(SEXP x, SEXP y);    // internal only
@@ -93,6 +97,7 @@ void copy_xtsCoreAttributes(SEXP x, SEXP y);// internal only
 
 int isXts(SEXP x);                          // is.xts analogue
 int firstNonNA(SEXP x);
+SEXP extract_col (SEXP x, SEXP j, SEXP drop, SEXP first_, SEXP last_);
 #endif /* _XTS */
 
 #ifdef __cplusplus
